PartnerMetadata

Struct PartnerMetadata 

pub struct PartnerMetadata {
Show 17 fields pub accept_gcp_tos: Option<bool>, pub additional_comments: Option<String>, pub confirm_partner_requirements: Option<bool>, pub demo_uri: Option<String>, pub has_dynamic_spec_uri: Option<bool>, pub integration_templates: Option<String>, pub local_spec_path: Option<String>, pub marketplace_product: Option<String>, pub marketplace_product_id: Option<String>, pub marketplace_product_project_id: Option<String>, pub marketplace_product_uri: Option<String>, pub partner: Option<String>, pub partner_connector_display_name: Option<String>, pub publish_request_time: Option<DateTime<Utc>>, pub target_application: Option<String>, pub target_customer_segment: Option<String>, pub use_cases: Option<String>,
}
Partner metadata details. This will be populated when publishing the custom connector as a partner connector version. On publishing, parntner connector version will be created using the fields in PartnerMetadata.

This type is not used in any activity, and only used as part of another schema.

Fields

accept_gcp_tos: Option<bool>

Required. Whether the user has accepted the Google Cloud Platform Terms of Service (https://cloud.google.com/terms/) and the Google Cloud Marketplace Terms of Service (https://cloud.google.com/terms/marketplace/launcher?hl=en).

additional_comments: Option<String>

Optional. Additional comments for the submission.

confirm_partner_requirements: Option<bool>

Required. Confirmation that connector meets all applicable requirements mentioned in the Partner Connector Publishing requirements list and Partner onboardiong requirements list (https://cloud.google.com/marketplace/docs/partners/get-started#requirements).

demo_uri: Option<String>

Required. Public URL for the demo video.

has_dynamic_spec_uri: Option<bool>

Output only. Has dynamic open api spec uri.

integration_templates: Option<String>

Required. Integration example templates for the custom connector.

local_spec_path: Option<String>

Output only. Local spec path. Required if has_dynamic_spec_uri is true.

marketplace_product: Option<String>

Optional. Marketplace product name.

marketplace_product_id: Option<String>

Required. Marketplace product ID.

marketplace_product_project_id: Option<String>

Optional. Marketplace product project ID.

marketplace_product_uri: Option<String>

Optional. Marketplace product URL.

partner: Option<String>

Required. Partner name.

partner_connector_display_name: Option<String>

Required. Partner connector display name.

publish_request_time: Option<DateTime<Utc>>

Output only. Publish request time.

target_application: Option<String>

Required. Target application for which partner connector is built.

target_customer_segment: Option<String>

Required. Target customer segment for the partner connector.

use_cases: Option<String>

Required. Details about partner connector use cases.