pub struct Connection {Show 35 fields
pub async_operations_enabled: Option<bool>,
pub auth_config: Option<AuthConfig>,
pub auth_override_enabled: Option<bool>,
pub billing_config: Option<BillingConfig>,
pub config_variables: Option<Vec<ConfigVariable>>,
pub connection_revision: Option<i64>,
pub connector_version: Option<String>,
pub connector_version_infra_config: Option<ConnectorVersionInfraConfig>,
pub connector_version_launch_stage: Option<String>,
pub create_time: Option<DateTime<Utc>>,
pub description: Option<String>,
pub destination_configs: Option<Vec<DestinationConfig>>,
pub envoy_image_location: Option<String>,
pub eua_oauth_auth_config: Option<AuthConfig>,
pub eventing_config: Option<EventingConfig>,
pub eventing_enablement_type: Option<String>,
pub eventing_runtime_data: Option<EventingRuntimeData>,
pub fallback_on_admin_credentials: Option<bool>,
pub host: Option<String>,
pub image_location: Option<String>,
pub is_trusted_tester: Option<bool>,
pub labels: Option<HashMap<String, String>>,
pub lock_config: Option<LockConfig>,
pub log_config: Option<ConnectorsLogConfig>,
pub name: Option<String>,
pub node_config: Option<NodeConfig>,
pub service_account: Option<String>,
pub service_directory: Option<String>,
pub ssl_config: Option<SslConfig>,
pub status: Option<ConnectionStatus>,
pub subscription_type: Option<String>,
pub suspended: Option<bool>,
pub tls_service_directory: Option<String>,
pub traffic_shaping_configs: Option<Vec<TrafficShapingConfig>>,
pub update_time: Option<DateTime<Utc>>,
}Expand description
Connection represents an instance of connector.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- locations connections create projects (request)
- locations connections get projects (response)
- locations connections patch projects (request)
Fields
async_operations_enabled: Option<bool>Optional. Async operations enabled for the connection. If Async Operations is enabled, Connection allows the customers to initiate async long running operations using the actions API.
auth_config: Option<AuthConfig>Optional. Configuration for establishing the connection’s authentication with an external system.
auth_override_enabled: Option<bool>Optional. Auth override enabled for the connection. If Auth Override is enabled, Connection allows the backend service auth to be overridden in the entities/actions API.
billing_config: Option<BillingConfig>Output only. Billing config for the connection.
config_variables: Option<Vec<ConfigVariable>>Optional. Configuration for configuring the connection with an external system.
connection_revision: Option<i64>Output only. Connection revision. This field is only updated when the connection is created or updated by User.
connector_version: Option<String>Required. Connector version on which the connection is created. The format is: projects//locations//providers//connectors//versions/* Only global location is supported for ConnectorVersion resource.
connector_version_infra_config: Option<ConnectorVersionInfraConfig>Output only. Infra configs supported by Connector Version.
connector_version_launch_stage: Option<String>Output only. Flag to mark the version indicating the launch stage.
create_time: Option<DateTime<Utc>>Output only. Created time.
description: Option<String>Optional. Description of the resource.
destination_configs: Option<Vec<DestinationConfig>>Optional. Configuration of the Connector’s destination. Only accepted for Connectors that accepts user defined destination(s).
envoy_image_location: Option<String>Output only. GCR location where the envoy image is stored. formatted like: gcr.io/{bucketName}/{imageName}
eua_oauth_auth_config: Option<AuthConfig>Optional. Additional Oauth2.0 Auth config for EUA. If the connection is configured using non-OAuth authentication but OAuth needs to be used for EUA, this field can be populated with the OAuth config. This should be a OAuth2AuthCodeFlow Auth type only.
eventing_config: Option<EventingConfig>Optional. Eventing config of a connection
eventing_enablement_type: Option<String>Optional. Eventing enablement type. Will be nil if eventing is not enabled.
eventing_runtime_data: Option<EventingRuntimeData>Output only. Eventing Runtime Data.
fallback_on_admin_credentials: Option<bool>Optional. Fallback on admin credentials for the connection. If this both auth_override_enabled and fallback_on_admin_credentials are set to true, the connection will use the admin credentials if the dynamic auth header is not present during auth override.
host: Option<String>Output only. The name of the Hostname of the Service Directory service with TLS.
image_location: Option<String>Output only. GCR location where the runtime image is stored. formatted like: gcr.io/{bucketName}/{imageName}
is_trusted_tester: Option<bool>Output only. Is trusted tester program enabled for the project.
labels: Option<HashMap<String, String>>Optional. Resource labels to represent user-provided metadata. Refer to cloud documentation on labels for more details. https://cloud.google.com/compute/docs/labeling-resources
lock_config: Option<LockConfig>Optional. Configuration that indicates whether or not the Connection can be edited.
log_config: Option<ConnectorsLogConfig>Optional. Log configuration for the connection.
name: Option<String>Output only. Resource name of the Connection. Format: projects/{project}/locations/{location}/connections/{connection}
node_config: Option<NodeConfig>Optional. Node configuration for the connection.
service_account: Option<String>Optional. Service account needed for runtime plane to access Google Cloud resources.
service_directory: Option<String>Output only. The name of the Service Directory service name. Used for Private Harpoon to resolve the ILB address. e.g. “projects/cloud-connectors-e2e-testing/locations/us-central1/namespaces/istio-system/services/istio-ingressgateway-connectors”
ssl_config: Option<SslConfig>Optional. Ssl config of a connection
status: Option<ConnectionStatus>Output only. Current status of the connection.
subscription_type: Option<String>Output only. This subscription type enum states the subscription type of the project.
suspended: Option<bool>Optional. Suspended indicates if a user has suspended a connection or not.
tls_service_directory: Option<String>Output only. The name of the Service Directory service with TLS.
traffic_shaping_configs: Option<Vec<TrafficShapingConfig>>Optional. Traffic shaping configuration for the connection.
update_time: Option<DateTime<Utc>>Output only. Updated time.